# Changelog

All notable changes to this project will be documented in this file.

## [0.2.2] - 2024-12-20

### 🚀 Features

- Allow specifying rev range in check command (#105)

### 📚 Documentation

- Add nosec comment to breaking change regex (#99)

### 🧪 Testing

- Add test for second line being empty (#100)
- Add test for message not being bytes (#101)
- Remove unnecessary print statement (#104)

### ⚙️ Miscellaneous Tasks

- Fix changelog generation by full checkout (#96)
- Fix run of bandit by using correct target (#97)
- Run bandit on tests (#98)
- Audit dependencies after installation (#102)
- Add merge group to check-code workflows to enable merge queues (#103)

<!-- generated by git-cliff -->
